/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core;

import java.util.Map;

/**
 * 
 * InitializationParameters is an interface for components that can be loaded 
 * with zero or more name-value pairs for configuration.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface InitializationParameters
{
    /**
     * 
     * @param name
     * 
     * @return The value of the initialization parameter, or null if it does 
     *         not exist.
     *
     */
    String getInitializationParameter(String name);

    /**
     * 
     * @return The set of name-value pairs provided at initialization time. 
     *         The Map may be empty.
     *
     */
    Map getInitializationParameters();

    /**
     * 
     * Allows the resource's creator to provide it with arbitrary name-value 
     * pairs that may be used during initialization. The way that these 
     * values are used and/or stored is an implementation detail, and there 
     * is no requirement that this feature be used - it is a generic way to 
     * specify deployment/initialization parameters. This method <b>should</b> 
     * be called before the resource is initialized.
     * 
     * @param parameters
     *        A simple set of name-value pairs - Map[String, String] - that 
     *        contains initialization parameters for the resource.
     *
     */
    void setInitializationParameters(Map parameters);
}
