/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.descriptor;

import javax.xml.namespace.QName;

/**
 *
 * This class provides all of the names used in the Muse deployment 
 * descriptor's schema (muse.xml). 
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class DescriptorConstants
{
    /**
     * 
     * The target namespace for the Muse deployment descriptor
     * 
     */
    public static final String NAMESPACE_URI = "http://ws.apache.org/muse/descriptor";

    public static final String PREFIX = "desc";
    
    /**
     * 
     * This is the standard name for descriptor files. All applications should 
     * be described using a file with the given name, located somewhere in 
     * the application's installation directory.
     * 
     */
    public static final String DESCRIPTOR_FILE_NAME = "muse.xml";
    
    public static final QName CAPABILITY_QNAME = 
        new QName(NAMESPACE_URI, "capability", PREFIX);
    
    public static final QName CAPABILITY_URI_QNAME = 
        new QName(NAMESPACE_URI, "capability-uri", PREFIX);
    
    public static final QName CONTEXT_PATH_QNAME = 
        new QName(NAMESPACE_URI, "context-path", PREFIX);
    
    public static final QName CUSTOM_SERIALIZER_QNAME = 
        new QName(NAMESPACE_URI, "custom-serializer", PREFIX);
    
    public static final QName INIT_PARAM_QNAME = 
        new QName(NAMESPACE_URI, "init-param", PREFIX);
    
    public static final QName JAVA_CAPABILITY_QNAME = 
        new QName(NAMESPACE_URI, "java-capability-class", PREFIX);
    
    public static final QName JAVA_ID_FACTORY_QNAME = 
        new QName(NAMESPACE_URI, "java-id-factory-class", PREFIX);
    
    public static final QName JAVA_PERSISTENCE_QNAME = 
        new QName(NAMESPACE_URI, "java-persistence-class", PREFIX);
    
    public static final QName JAVA_RESOURCE_QNAME = 
        new QName(NAMESPACE_URI, "java-resource-class", PREFIX);
    
    public static final QName JAVA_ROUTER_QNAME = 
        new QName(NAMESPACE_URI, "java-router-class", PREFIX);
    
    public static final QName JAVA_SERIALIZABLE_QNAME = 
        new QName(NAMESPACE_URI, "java-serializable-type", PREFIX);
    
    public static final QName JAVA_SERIALIZER_QNAME = 
        new QName(NAMESPACE_URI, "java-serializer-class", PREFIX);
    
    public static final QName LOG_FILE_QNAME = 
        new QName(NAMESPACE_URI, "log-file", PREFIX);
    
    public static final QName LOG_LEVEL_QNAME = 
        new QName(NAMESPACE_URI, "log-level", PREFIX);
    
    public static final QName LOGGING_QNAME = 
        new QName(NAMESPACE_URI, "logging", PREFIX);
    
    public static final QName MUSE_QNAME = 
        new QName(NAMESPACE_URI, "muse", PREFIX);
    
    public static final QName PARAM_NAME_QNAME = 
        new QName(NAMESPACE_URI, "param-name", PREFIX);
    
    public static final QName PARAM_VALUE_QNAME = 
        new QName(NAMESPACE_URI, "param-value", PREFIX);
    
    public static final QName PERSISTENCE_LOCATION_QNAME = 
        new QName(NAMESPACE_URI, "persistence-location", PREFIX);
    
    public static final QName PERSISTENCE_QNAME = 
        new QName(NAMESPACE_URI, "persistence", PREFIX);
    
    public static final QName RESOURCE_TYPE_QNAME = 
        new QName(NAMESPACE_URI, "resource-type", PREFIX);

    public static final QName ROUTER_QNAME = 
        new QName(NAMESPACE_URI, "router", PREFIX);

    public static final String USE_ROUTER_PERSISTENCE = "use-router-persistence";

    public static final QName WSDL_FILE_QNAME = 
        new QName(NAMESPACE_URI, "wsdl-file", PREFIX);
    
    public static final QName WSDL_PORT_TYPE_QNAME = 
        new QName(NAMESPACE_URI, "wsdl-port-type", PREFIX);
    
    public static final QName WSDL_QNAME = 
        new QName(NAMESPACE_URI, "wsdl", PREFIX);
}
