/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.core.routing;

import javax.xml.namespace.QName;

/**
 *
 * ResourceIdFactory is an interface for classes that provide a name-value 
 * pair that is inserted into a WS-Addressing endpoint reference's set of 
 * properties in order to distinguish it from other EPRs that target the 
 * same endpoint (the implied resource pattern). The resource creation 
 * process uses instances of this interface to provide the resource with a 
 * unique EPR. You can set which ResourceIdFactory is used for a resource type 
 * using the <em>java-id-factory-class</em> element in muse.xml.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface ResourceIdFactory
{
    /**
     * 
     * @return The name of the WS-A reference property to be added to the 
     *         resource's EPR for identification.
     *
     */
    QName getIdentifierName();
    
    /**
     * 
     * @return A unique value that has not been used for other manageable 
     *         resources.
     *
     */
    String getNextIdentifier();
}
