/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/


package org.apache.muse.core.platform.osgi.axis2.internal;

import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;

import javax.wsdl.Definition;
import javax.wsdl.WSDLException;
import javax.wsdl.factory.WSDLFactory;
import javax.wsdl.xml.WSDLWriter;
import javax.xml.namespace.QName;

import org.apache.axis2.AxisFault;
import org.apache.axis2.description.AxisOperation;
import org.apache.axis2.description.InOutAxisOperation;
import org.apache.axis2.description.AxisService;
import org.apache.axis2.description.Parameter;
import org.apache.axis2.wsdl.WSDLConstants;
import org.osgi.framework.Bundle;

/**
 * Axis2ResourceManagementService represents the Muse <code>IsolationLayer</code> to the Axis runtime.  
 * The service intializes an operation for the <code>IsolationLayer handleRequest</code> operation
 * and sets the message receiver for that operation to an instance of 
 * <code>OSGiRawXMLInOutMessageReceiver</code>
 * 
 * @see OSGiRawXMLInOutMessageReceiver
 * @see org.apache.muse.core.platform.IsolationLayer
 * 
 * @author Joel Hawkins
 *
 */
public class Axis2ResourceManagementService extends AxisService {

	private AxisOperation isolationLayerOperation;
	private String wsdlPath;
	private Bundle bundle;

	/**
	 * Constructs the service and initializes an operation for the 
	 * <code>IsolationLayer handleRequest</code> operation  
	 */
	public Axis2ResourceManagementService(){
		super();
		isolationLayerOperation = new InOutAxisOperation();
		isolationLayerOperation.setName(new QName("handleRequest"));
		isolationLayerOperation.setMessageReceiver(new OSGiRawXMLInOutMessageReceiver());
	}

	/**
	 * gets the requested operation from this service. If no operation is found,  
	 * the <code>handleRequest</code> operation is returned.
	 * @param operationName  the QName of the requested operation
	 * @return the <code>AxisOperation</code> corresponding to the <code>operationName</code> or
	 *         the <code>handleOperation</code> if the <code>operationName</code> is not found   
	 */
    public AxisOperation getOperation(QName operationName) {
      AxisOperation axisOperation = super.getOperation(operationName);

      if (axisOperation == null) {
          axisOperation = isolationLayerOperation;
      }

      return axisOperation;
    }
    
    public void setWSDLPath(String wsdlPath){
    	this.wsdlPath = wsdlPath;
    }
    
    public void setBundle(Bundle bundle){
    	this.bundle = bundle;
    }
    
    public void printWSDL(OutputStream out, String requestIP, String servicePath) throws AxisFault {
    	if(wsdlPath != null && bundle != null){
    		try {
    			URL wsdlURL = bundle.getResource(wsdlPath);
    			if(wsdlURL != null){
    				InputStream stream = wsdlURL.openStream();
    				byte buffer[] = new byte[512];
    				int read = 0;
    				while((read = stream.read(buffer)) > 0){
    					out.write(buffer, 0, read);
    				}
    			}
    		} catch(Throwable t){
    			//prints an error message...
    			//TODO - uncomment once we get a real Axis2 1.1
    			//super.printWSDL(out, requestIP, servicePath);
    			throw new AxisFault("Wsdl not found for " + servicePath);
    		}
    	}else {
			//TODO - uncomment once we get a real Axis2 1.1
			//super.printWSDL(out, requestIP, servicePath);
			throw new AxisFault("Wsdl not found for " + servicePath);
    	}
    }
  
}
