/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.tools.generator.analyzer;

import org.apache.muse.tools.generator.util.Configurable;
import org.apache.muse.tools.generator.util.ConfigurationData;

/**
 * 
 * Analyzer is an interface for the analysis phase of code generation.
 * This piece should read in descriptors (like WSDL, RMD, etc.) and 
 * should produce at the very least a set of <code>Capability</code> 
 * objects that can be passed on to the later stages (Synthesis, Projectization).
 *
 * @author Andrew Eberbach (aeberbac)
 */

public interface Analyzer extends Configurable {
	
	/**
	 * Perform the analysis portion of code generation. 
	 * 
	 * @param data 
	 * 			   <code>ConfiguartionData</code> containing the necessary
	 * 			   parameters to do the analysis. Each Analyzer will have different 
	 * 			   requirements which can be queried using the <code>Configurable</code>
	 * 			   interface. 
	 * 				
	 * @return 
	 * 			   A new <code>ConfigurationData</code> which has been cloned from the original
	 * 		       which contains the results of the analysis.
	 * 
	 * @throws Exception 
	 * 			   If any problems occur during analysis.
	 * 
	 * @see org.apache.muse.tools.generator.util.Configurable
	 */
	ConfigurationData analyze(ConfigurationData data) throws Exception;
}