/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.WsResource;
import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * Correlation represents the expression in one instance of the 
 * CorrelatableProperties resource property. Instances of this type can be 
 * used to determine if two endpoints point to the same resource instance.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface Correlation extends XmlSerializable
{
    /**
     * 
     * @return The dialect, or type, of the correlation expression. Users 
     *         may define their own correlation types and declare the syntax 
     *         with this method.
     *
     */
    String getDialect()
        throws BaseFault;
    
    /**
     * 
     * @return The local resource that is defining the CorrelatableProperties 
     *         capability and, thus, this correlation expression.
     *
     */
    WsResource getWsResource();
    
    /**
     * 
     * @return True if there is a guarantee that two resources are not the 
     *         same when matches(Resource) returns 'false'. If this method 
     *         returns 'false', the caller must rely on some other means to 
     *         confirm that the resources are, in fact, different.
     *
     */
    boolean hasNegativeAssertion()
        throws BaseFault;
    
    /**
     * 
     * @param epr
     *        The EPR of another resource which may be the same as this 
     *        resource.
     * 
     * @return True if the two resources are the same according to their 
     *         WSDM ResourceId values or their WSDM CorrelatableProperties 
     *         expressions. Note that if the method returns 'false', this 
     *         does not guarantee that the two resources are actually 
     *         different - you can only confirm this by checking with the 
     *         hasNegativeAssertions() method.
     * 
     * @throws SoapFault
     *         <ul>
     *         <li>If there is a problem reading the correlatable properties 
     *         from either resource.</li>
     *         <li>If the values or dialects of the correlatable properties 
     *         are not supported. The built-in dialects are WSDM Property 
     *         Boolean Match (PBM) and XPath 1.0.</li>
     *         </ul>
     * 
     * @see #hasNegativeAssertion()
     *
     */
    boolean matches(EndpointReference epr)
        throws SoapFault;
}
