/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws;

import javax.xml.namespace.QName;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * RelationshipResource is the interface that describes WSDM relationships as 
 * WS-RF implied resources. Resources that use this capability represent the 
 * relationships that exist between other WS-resources in a system and should 
 * not, as a general rule, have any other significant state or interface.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface RelationshipResource 
    extends ManageabilityCapability, XmlSerializable
{
    QName[] PROPERTIES = new QName[]{
        MuwsConstants.NAME_QNAME, 
        MuwsConstants.TYPE_QNAME, 
        MuwsConstants.PARTICIPANT_QNAME, 
        MuwsConstants.ACCESS_EPR_QNAME
    };
    
    /**
     * 
     * @return The relationship resource's EPR - this should be the same 
     *         value returned by Resource.getEndpointReference().
     *         
     * @see org.apache.muse.core.Resource#getEndpointReference
     *
     */
    EndpointReference getAccessEndpointReference()
        throws BaseFault;
    
    /**
     * 
     * @return A descriptive name for this relationship.
     *
     */
    String getName()
        throws BaseFault;

    /**
     * 
     * @return The type of this relationship, as defined by an XSD complex type.
     *
     */
    RelationshipType getType()
        throws BaseFault;

    /**
     * 
     * @return The participants in this relationship. The array will have 
     *         a length of at least 2.
     *
     */
    Participant[] getParticipant()
        throws BaseFault;
    
    void setName(String name)
        throws BaseFault;
    
    void setType(RelationshipType type)
        throws BaseFault;
    
    /**
     * 
     * @param participants
     *        The participants in this relationship. The array must have 
     *         a length of at least 2.
     *
     */
    void setParticipant(Participant[] participants)
        throws BaseFault;
}
