/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import java.util.Date;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.dm.muws.Metric;
import org.apache.muse.ws.dm.muws.MuwsConstants;
import org.apache.muse.ws.resource.properties.listeners.PropertyReadListener;
import org.apache.muse.util.xml.XsdUtils;

/**
 *
 * MetricDecorationProvider is a simple property listener that adds the standard 
 * WSDM MetricAttributes attributes to a property's XML definition. This 
 * listener is invoked just before the property's XML is returned to a client 
 * during a WS-RP read. It takes the metric's metadata and adds it to the XML 
 * being returned without modifying the WS-RP collection itself.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class MetricDecorationProvider implements PropertyReadListener
{
    private Metric _metric = null;
    
    public MetricDecorationProvider(Metric metric)
    {
        _metric = metric;
    }

    public QName getPropertyName()
    {
        return _metric.getName();
    }

    public Element[] readRequested(Element[] properties)
    {
        for (int n = 0; n < properties.length; ++n)
        {
            //
            // there are three possible attributes: LastUpdated, ResetAt, Duration
            //
            Date lastUpdate = _metric.getLastUpdated();
            Date reset = _metric.getResetAt();
            String duration = _metric.getDuration();
            
            //
            // this listener doesn't have to do any validation to see what 
            // attributes should be used - that is the job of Metric. all 
            // we do here is add the values if they exist
            //
            
            if (lastUpdate != null)
            {
                String timeString = XsdUtils.getLocalTimeString(lastUpdate);
                properties[n].setAttribute(MuwsConstants.LAST_UPDATED, timeString);
            }
            
            if (reset != null)
            {
                String timeString = XsdUtils.getLocalTimeString(reset);
                properties[n].setAttribute(MuwsConstants.RESET_AT, timeString);
            }
            
            if (duration != null)
                properties[n].setAttribute(MuwsConstants.DURATION, duration);
        }
        
        return properties;
    }
}
