/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.impl;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.dm.muws.MuwsConstants;
import org.apache.muse.ws.dm.muws.Participant;
import org.apache.muse.ws.dm.muws.RelationshipResource;
import org.apache.muse.ws.dm.muws.RelationshipType;

/**
 *
 * SimpleRelationshipResource is Muse's default implementation of the MUWS (Part 2) 
 * RelationshipResource capability.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleRelationshipResource 
    extends AbstractManageabilityCapability implements RelationshipResource
{
    //
    // Used to look up all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(SimpleRelationshipResource.class);
    
    private String _name = null;
    
    private Participant[] _participants = null;
    
    private RelationshipType _type = null;

    public EndpointReference getAccessEndpointReference()
    {
        return getResource().getEndpointReference();
    }
    
    public String getName()
    {
        return _name;
    }
    
    public Participant[] getParticipant()
    {
        return _participants;
    }

    public QName[] getPropertyNames()
    {
        return PROPERTIES;
    }

    public RelationshipType getType()
    {
        return _type;
    }

    public void setName(String name)
    {
        _name = name;
    }

    public void setParticipant(Participant[] participants)
    {
        if (participants == null)
            throw new NullPointerException(_MESSAGES.get("NullParticipants"));
        
        _participants = participants;
    }

    public void setType(RelationshipType type)
    {
        if (type == null)
            throw new NullPointerException(_MESSAGES.get("NullRelationshipType"));
        
        _type = type;
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        if (doc == null)
            throw new NullPointerException(_MESSAGES.get("NullDocument"));
        
        Element root = XmlUtils.createElement(doc, MuwsConstants.RELATIONSHIP_QNAME);
        
        Element eprXML = getWsResource().getEndpointReference().toXML();
        XmlUtils.setElement(root, MuwsConstants.ACCESS_EPR_QNAME, eprXML);
        
        String name = getName();
        
        if (name != null)
            XmlUtils.setElement(root, MuwsConstants.NAME_QNAME, name);
        
        Element typeXML = getType().toXML(doc);
        XmlUtils.setElement(root, MuwsConstants.TYPE_QNAME, typeXML);
        
        Participant[] participants = getParticipant();
        
        for (int n = 0; n < participants.length; ++n)
        {
            Element participantXML = participants[n].toXML(doc);
            root.appendChild(participantXML);
        }
        
        return root;
    }
}
