/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.dm.muws.events;

import java.util.Date;

import org.apache.muse.util.xml.XmlSerializable;

/**
 *
 * ManagementEvent defines the even type of the WSDM Event Format (WEF). 
 * It is composed of accessor methods for its fields and serialization 
 * methods for convertion to and from XML. Event objects should be 
 * created with a {@WefFactory WefFactory}.
 * <br><br> 
 * <code>
 * WefFactory factory = new SimpleWefFactory();<br>
 * ManagementEvent event = factory.createEvent();<br>
 * event.setSequenceNumber(1234);
 * <br>// etc.<br>
 * <br>
 * </code>
 * The factory will also have methods for instantiating the event from XML.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface ManagementEvent extends XmlSerializable, ExtendedElements
{
    String getEventID();

    Component getReporter();

    Date getReportTime();
    
    long getSequenceNumber();

    Situation getSituation();

    Component getSource();
    
    void setEventID(String eventID);

    void setReporter(Component reporter);

    void setReportTime(Date reportTime);
    
    void setSequenceNumber(long sequenceNumber);

    void setSituation(Situation situation);

    void setSource(Component source);
}
