/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.notification.remote;

import org.apache.muse.core.Environment;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.EndpointReference;
import org.apache.muse.ws.notification.NotificationMessage;
import org.apache.muse.ws.notification.WsnConstants;
import org.apache.muse.ws.resource.remote.WsResourceClient;
import org.apache.muse.ws.addressing.soap.SoapClient;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.w3c.dom.Element;

/**
 *
 * NotificationConsumerClient is a web services client for resources that 
 * implement the WS-N NotificationConsumer port type. It adds the wsnt:Notify 
 * method to the base WS-RF interfaces.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class NotificationConsumerClient extends WsResourceClient
{
    public NotificationConsumerClient(EndpointReference destination)
    {
        super(destination);
    }
    
    public NotificationConsumerClient(EndpointReference destination, 
                                      EndpointReference source)
    {
        super(destination, source);
    }
    
    public NotificationConsumerClient(EndpointReference destination, 
                                      EndpointReference source, 
                                      Environment environment)
    {
        super(destination, source, environment);
    }
    
    public NotificationConsumerClient(EndpointReference destination, 
                                      EndpointReference source, 
                                      SoapClient soapClient)
    {
        super(destination, source, soapClient);
    }
        
    public EndpointReference getProducerReference()
    {
        return getSource();
    }
    
    public EndpointReference getConsumerReference()
    {
        return getDestination();
    }
    
    public void notify(NotificationMessage message)
        throws SoapFault
    {
        notify(new NotificationMessage[]{ message });
    }

    public void notify(NotificationMessage[] messages)
        throws SoapFault
    {
        EndpointReference epr = getProducerReference();
        
        for (int n = 0; n < messages.length; ++n)
            messages[n].setProducerReference(epr);
        
        Element notify = XmlUtils.createElement(WsnConstants.NOTIFY_QNAME);
        
        for (int n = 0; n < messages.length; ++n)
            notify.appendChild(messages[n].toXML());
        
        invoke(WsnConstants.NOTIFY_URI, notify);
    }
}
