/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource;

import org.apache.muse.core.Resource;
import org.apache.muse.ws.resource.properties.ResourcePropertyCollection;

/**
 * 
 * WsResource is an extension of the core Muse Resource component. It adds the 
 * concept of a state model via WS-ResourceProperties. Note that the addition 
 * of the WSRP ResourcePropertyCollection does <b>not</b> imply that WsResource 
 * resource types have to expose any of the WSRP capabilities. The state model 
 * will be available no matter how many WSRP capabilities are exposed to remote 
 * clients, if any; the WSRP capabilities themselves will simply push down on 
 * the ResourcePropertyCollection as part of their implementations.
 *  
 * @author Dan Jemiolo (danj)
 * 
 */

public interface WsResource extends Resource
{
    /**
     * 
     * @return The internal WSRP state model - despite the fact that this has 
     *         all of the WSRP operations available, none of them is exposed 
     *         to remote clients until one or more of the WSRP capabilities 
     *         is used in the resource's definition.
     *         
     * @see org.apache.muse.ws.resource.properties.get.GetCapability
     * @see org.apache.muse.ws.resource.properties.query.QueryCapability
     * @see org.apache.muse.ws.resource.properties.set.SetCapability
     *
     */
    ResourcePropertyCollection getPropertyCollection();
}
