/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 * 
 * WsResourceCapabilityProperties is a collection of generic, WSRP-like methods 
 * that can be used by the WSRP ResourcePropertyCollection (or any other code) 
 * to read and write a capability's property values. In the case of the WSRP 
 * implementation, these methods will be used as part of its delegation model, 
 * wherein the capability is responsible for the maintenance of its properties 
 * and the WSRP implementation provides any WSRP-specific logic related to 
 * permissions, validation, and faults.
 *
 * @author Dan Jemiolo (danj)
 *
 */

interface WsResourceCapabilityProperties
{
    void deleteProperty(QName property) 
        throws BaseFault;
    
    Element[] getProperty(QName property)
        throws BaseFault;
    
    /**
     * 
     * Concrete capability classes that define properties <b>MUST</b> override 
     * this method and provide the names of the properties.
     * 
     * @return The names of the resource properties defined by this capability.
     *
     */
    QName[] getPropertyNames();
    
    void insertProperty(QName property, Element[] values)
        throws BaseFault;
    
    void updateProperty(QName property, Element[] values)
        throws BaseFault;
}
