/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties;

import javax.xml.namespace.QName;

/**
*
* WsrpConstants is a collection of properties and methods that is useful when 
* programming against the WS-ResourceProperties spec. This class uses WS-RP v1.2.
*
* @author Dan Jemiolo (danj)
*
*/

public class WsrpConstants
{
    public static final String NAMESPACE_URI = "http://docs.oasis-open.org/wsrf/rp-2";
    
    public static final String PREFIX = "wsrf-rp";

    public static final String WSDL_NAMESPACE_URI = "http://docs.oasis-open.org/wsrf/rpw-2";
    
    public static final String WSDL_PREFIX = "wsrf-rpw";
    
    public static final String GET_CAPABILITY = WSDL_NAMESPACE_URI + "/Get";
    
    public static final String SET_CAPABILITY = WSDL_NAMESPACE_URI + "/Set";
    
    public static final String QUERY_CAPABILITY = WSDL_NAMESPACE_URI + "/Query";
    
    /**
     * 
     * A default root element name for WS-RP documents.
     * 
     */
    public static final QName DEFAULT_DOCUMENT_QNAME = 
        new QName(NAMESPACE_URI, "ResourceProperties", PREFIX);
    
    public static final QName DELETE_QNAME = 
        new QName(NAMESPACE_URI, "Delete", PREFIX);
    
    public static final String DIALECT = "Dialect";

    public static final QName GET_DOCUMENT_QNAME = 
        new QName(NAMESPACE_URI, "GetResourcePropertyDocument", PREFIX);

    public static final QName GET_DOCUMENT_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "GetResourcePropertyDocumentResponse", PREFIX);

    /**
     * 
     * The WS-A Action URI for the GetMultipleResourceProperties operation.
     * 
     */
    public static final String GET_MULTIPLE_PROPERTIES_URI = 
        WSDL_NAMESPACE_URI + "/GetMultipleResourceProperties/GetMultipleResourcePropertiesRequest";

    public static final QName GET_MULTIPLE_QNAME = 
        new QName(NAMESPACE_URI, "GetMultipleResourceProperties", PREFIX);

    public static final QName GET_MULTIPLE_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "GetMultipleResourcePropertiesResponse", PREFIX);
    
    public static final QName GET_QNAME = 
        new QName(NAMESPACE_URI, "GetResourceProperty", PREFIX);
    
    /**
     * 
     * The WS-A Action URI for the GetResourceProperty operation.
     * 
     */
    public static final String GET_RESOURCE_PROPERTY_URI = 
        WSDL_NAMESPACE_URI + "/GetResourceProperty/GetResourcePropertyRequest";
    
    public static final QName GET_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "GetResourcePropertyResponse", PREFIX);

    /**
     * 
     * The WS-A Action URI for the GetResourcePropertyDocument operation.
     * 
     */
    public static final String GET_RP_DOCUMENT_URI = 
        WSDL_NAMESPACE_URI + "/GetResourcePropertyDocument/GetResourcePropertyDocumentRequest";
    
    public static final QName INSERT_QNAME = 
        new QName(NAMESPACE_URI, "Insert", PREFIX);
    
    public static final QName INVALID_MODIFICATION_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "InvalidModificationFault", WSDL_PREFIX);
    
    public static final QName INVALID_PROPERTY_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "InvalidResourcePropertyQNameFault", WSDL_PREFIX);

    public static final QName INVALID_QUERY_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "InvalidQueryExpressionFault", WSDL_PREFIX);

    /**
     * 
     * WS-RP/WS-N change notification - new value element name.
     * 
     */
    public  static final QName NEW_VALUES_QNAME = 
        new QName(NAMESPACE_URI, "NewValues", PREFIX);
    
    /**
     * 
     * WS-RP/WS-N change notification - root element name.
     * 
     */
    public static final QName NOTIFICATION_QNAME = 
        new QName(NAMESPACE_URI, "ResourcePropertyValueChangeNotification", PREFIX);
    
    /**
     * 
     * WS-RP/WS-N change notification - old value element name.
     * 
     */
    public static final QName OLD_VALUES_QNAME = 
        new QName(NAMESPACE_URI, "OldValues", PREFIX);
    
    public static final QName PROPERTY_QNAME = 
        new QName(NAMESPACE_URI, "ResourceProperty", PREFIX);
    
    public static final QName PUT_DOCUMENT_QNAME = 
        new QName(NAMESPACE_URI, "PutResourcePropertyDocument", PREFIX);
    
    /**
     * 
     * The WS-A Action URI for the PutResourcePropertyDocument operation.
     * 
     */
    public static final String PUT_RP_DOCUMENT_URI = 
        WSDL_NAMESPACE_URI + "/PutResourcePropertyDocument/PutResourcePropertyDocumentRequest";

    public static final QName QUERY_DIALECT_QNAME = 
        new QName(NAMESPACE_URI, "QueryExpressionDialect", PREFIX);
    
    public static final QName QUERY_EVALUATION_ERROR_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "QueryEvaluationErrorFault", WSDL_PREFIX);
    
    public static final QName QUERY_EXPRESSION_QNAME = 
        new QName(NAMESPACE_URI, "QueryExpression", PREFIX);
    
    public static final QName QUERY_QNAME = 
        new QName(NAMESPACE_URI, "QueryResourceProperties", PREFIX);
    
    /**
     * 
     * The WS-A Action URI for the QueryResourceProperties operation.
     * 
     */
    public static final String QUERY_RESOURCE_PROPERTIES_URI = 
        WSDL_NAMESPACE_URI + "/QueryResourceProperties/QueryResourcePropertiesRequest";
    
    public static final QName QUERY_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "QueryResourcePropertiesResponse", PREFIX);
    
    /**
     * 
     * The WS-RP attribute for WSDL portTypes.
     * 
     */
    public static final String RESOURCE_PROPERTIES = "ResourceProperties";
    
    public static final String RESOURCE_PROPERTY = "ResourceProperty";
    
    public static final QName SET_QNAME = 
        new QName(NAMESPACE_URI, "SetResourceProperties", PREFIX);
    
    /**
     * 
     * The WS-A Action URI for the SetResourceProperties operation.
     * 
     */
    public static final String SET_RESOURCE_PROPERTIES_URI = 
        WSDL_NAMESPACE_URI + "/SetResourceProperties/SetResourcePropertiesRequest";

    public static final QName SET_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "SetResourcePropertiesResponse", PREFIX);

    public static final QName SET_RP_FAILED_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "SetResourcePropertyRequestFailedFault", WSDL_PREFIX);

    /**
     * 
     * The standard WS-RP TopicSpace name.
     * 
     */
    public static final String TOPIC_SPACE_NAME = "ResourcePropertiesTopicSpace";

    public static final QName UNABLE_TO_MODIFY_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "UnableToModifyResourcePropertyFault", WSDL_PREFIX);
        
    public static final QName UNABLE_TO_PUT_RP_QNAME = 
      new QName(WSDL_NAMESPACE_URI, "UnableToPutResourcePropertyDocumentFault", WSDL_PREFIX);
    
    public static final QName UNKNOWN_QUERY_DIALECT_QNAME = 
        new QName(WSDL_NAMESPACE_URI, "UnknownQueryExpressionDialectFault", WSDL_PREFIX);
    
    public static final QName UPDATE_QNAME = 
        new QName(NAMESPACE_URI, "Update", PREFIX);
}
