/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.get;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.get.faults.InvalidResourcePropertyQNameFault;

/**
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface GetResourceProperty
{
    /**
     * 
     * Returns zero or more instances of the given property.
     *
     * @param qname
     *        The name of the property to find.
     * 
     * @return An array of DOM Elements, where each Element is an instance 
     *         of the property named. There is no guarantee that the Elements 
     *         are the internal data structures used by the WS-RP document.
     * 
     * @throws InvalidResourcePropertyQNameFault
     *         <ul>
     *         <li>If the property is undefined in the document's schema. This 
     *         is <b>not</b> the same as finding zero instances of a defined 
     *         property.</li>
     *         </ul>
     *
     */
    Element[] getResourceProperty(QName qname) 
        throws InvalidResourcePropertyQNameFault, BaseFault;
}
