/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.listeners;

import javax.xml.namespace.QName;

/**
 *
 * AbstractChangeApprover is an abstract base class that implements the 
 * identification and security aspects of 
 * {@linkplain PropertyChangeApprover PropertyChangeApprover}. Concrete 
 * approvers that subclass this class only have to implement the 
 * PropertyChangeApprover.validateChange() method. 
 *
 * @author Dan Jemiolo (danj)
 *
 */

public abstract class AbstractChangeApprover implements PropertyChangeApprover
{
    //
    // The name of the property to protect
    //
    private QName _qname = null;
    
    //
    // The security token of the WS-RP container - we can compare this 
    // against other tokens to determine of the request is coming from 
    // inside the application or from external requests.
    //
    private Object _securityToken = null;
    
    /**
     * 
     * Creates a new approver for the property with the given name.
     *
     * @param qname
     *        The QName of the property to monitor.
     *
     */
    public AbstractChangeApprover(QName qname)
    {
        _qname = qname;
    }
    
    public QName getPropertyName()
    {
        return _qname;
    }
    
    /**
     * 
     * @return True if the given token is the same object as the internal 
     *         security token, or if they match according to equals().
     *
     */
    public boolean isSecure(Object outsideToken)
    {
        return _securityToken == outsideToken || 
               (_securityToken != null && _securityToken.equals(outsideToken));
    }
    
    public void setSecurityToken(Object securityToken)
    {
        _securityToken = securityToken;
    }
}
