/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.listeners;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 *
 * PropertyChangeListener describes a type of property listener that is 
 * invoked after a property change has occurred (through the WS-RP 
 * SetResourceProperties operation). Listeners can react to or report the 
 * change from the propertyChanged() method. If you want to prevent changes, 
 * you should use a {@linkplain PropertyChangeApprover PropertyChangeApprover}. 
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface PropertyChangeListener
{
    /**
     * 
     * @return The QName of the property to monitor.
     *
     */
    QName getPropertyName();
    
    /**
     * 
     * Receives the old and new value of the property after it has been 
     * changed; there are no requirements on the actions taken in response 
     * to a property change.
     *
     * @param oldValue
     *        A copy of the property instance before it was changed.
     * 
     * @param newValue
     *        The current value of the property instance.
     * 
     * @throws BaseFault
     *         <ul>
     *         <li>If the change reaction fails for any reason.</li>
     *         </ul>
     *
     */
    void propertyChanged(Element oldValue, Element newValue)
        throws BaseFault;
}
