/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.set;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.ResourcePropertyCollection;

/**
 * 
 * SetRequestComponent is the atomic unit of construction for WSRP 
 * SetResourceProperties requests. Instances of this type can be 
 * executed against a {@linkplain ResourcePropertyCollection WSRP document}. 
 * There is a finite set of concrete SetRequestComponent types, and they are 
 * defined by the WSRP v1.2 spec.
 *
 * @author Dan Jemiolo (danj)
 *
 *
 */

public interface SetRequestComponent extends XmlSerializable
{
    /**
     * 
     * Performs the set command on the given WSRP document. There may be 
     * one or more changes made to the document as the result of this command.
     *
     */
    void execute(ResourcePropertyCollection props)
        throws BaseFault;
    
    int getNumberOfValues();
    
    /**
     * 
     * @return The name of the property being operated on.
     *
     */
    QName getPropertyName();
    
    /**
     * 
     * @return The security token assigned by the command's creator, which 
     *         may affect its ability to execute successfully.
     *
     */
    Object getSecurityToken();

    Element getValue(int index);

    Element[] getValues();

    void setPropertyName(QName qname);

    void setSecurityToken(Object securityToken);

    void setValues(Object[] values);
}
