/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.set;

import org.apache.muse.ws.resource.basefaults.BaseFault;
import org.apache.muse.ws.resource.properties.get.faults.InvalidResourcePropertyQNameFault;
import org.apache.muse.ws.resource.properties.set.faults.InvalidModificationFault;
import org.apache.muse.ws.resource.properties.set.faults.SetResourcePropertyRequestFailedFault;
import org.apache.muse.ws.resource.properties.set.faults.UnableToModifyResourcePropertyFault;

/**
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public interface SetResourceProperties
{
    /**
     * 
     * Modifies one or more property instances according to the definition 
     * of the three WS-RP write operations: Insert, Update, and Delete. 
     * The operations in the request are processed in order. There is no 
     * transaction support as part of basic WS-RP, so if one operation fails, 
     * the operations that were completed before it will remain intact. 
     * 
     * @param request
     *        The SetResourceProperties request that contains the individual 
     *        operations { Insert, Update, Delete } to perform on the document.
     * 
     * @throws BaseFault
     *         <ul>
     *         <li>If one of the individual set operations fails. Please 
     *         review the different fault cases for each set operation in 
     *         the SetResourcePropertiesRequests interface.</li>
     *         </ul>
     * 
     * @see SetResourceProperties
     *
     */
    void setResourceProperties(SetRequest request) 
        throws InvalidResourcePropertyQNameFault, 
               InvalidModificationFault, 
               SetResourcePropertyRequestFailedFault, 
               UnableToModifyResourcePropertyFault, 
               BaseFault;
}
