/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.set;

import javax.xml.namespace.QName;

import org.apache.muse.ws.resource.basefaults.BaseFault;

/**
 * 
 * SetResourcePropertiesComponents breaks apart the WS-RP SetResourceProperties 
 * operation into a set of convenience methods. Each of the set operations 
 * { Insert, Update, Delete } now has its own method(s), allowing internal 
 * callers to perform modifications with much less plumbing code.
 * 
 * @author Dan Jemiolo (danj)
 *
 */
public interface SetResourcePropertiesComponents
{
    /**
     * 
     * Removes <b>all</b> properties with the given name.
     * 
     */
    void deleteResourceProperty(QName qname) 
        throws BaseFault;

    /**
     * 
     * Creates new instances of the given property using the given values.
     * 
     */
    void insertResourceProperty(QName qname, Object[] values) 
        throws BaseFault;

    /**
     * 
     * Replaces all of a property's current values with the given values.
     * 
     */
    void updateResourceProperty(QName qname, Object[] values) 
        throws BaseFault;

}
