/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.sg;

import javax.xml.namespace.QName;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.addressing.EndpointReference;

/**
 * 
 * MembershipContentRule represents the wsrf-sg:MembershipContentRule 
 * resource property defined by the WS-RF ServiceGroup resource type.
 * Aside from the fields that are included in the content rule definition, 
 * the interface also contains a method for evaluating the rules against 
 * a WS-resource.
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public interface MembershipContentRule extends XmlSerializable
{
    QName[] getContentElements();

    QName getMemberInterface();

    /**
     * 
     * @param epr
     *        The EPR for the resource against which this membership content 
     *        rule will be evaluated.
     * 
     * @return True if the given resource's WS-RP document matches the rules 
     *         in the MCR.
     *
     */
    boolean isMatch(EndpointReference epr);

    void setContentElements(QName[] content);

    void setMemberInterface(QName portType);
}
