/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.sg;

import javax.xml.namespace.QName;

/**
 *
 * WssgConstants is a collection of properties that is useful when programming 
 * against the WS-ServiceGroups spec. This class uses WS-SG v1.2.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class WssgConstants
{
    public static final String NAMESPACE_URI = "http://docs.oasis-open.org/wsrf/sg-2";
    
    public static final String PREFIX = "wsrf-sg";

    public static final String WSDL_NAMESPACE_URI = "http://docs.oasis-open.org/wsrf/sgw-2";
    
    public static final String WSDL_PREFIX = "wsrf-sgw";
    
    public static final String SERVICE_GROUP_URI = WSDL_NAMESPACE_URI + "/ServiceGroup";
    
    public static final String SERVICE_GROUP_REG_URI = WSDL_NAMESPACE_URI + "/ServiceGroupRegistration";
    
    public static final String ENTRY_URI = WSDL_NAMESPACE_URI + "/ServiceGroupEntry";
    
    public static final QName ADD_QNAME = 
        new QName(NAMESPACE_URI, "Add", PREFIX);
    
    public static final QName ADD_REFUSED_QNAME = 
        new QName(NAMESPACE_URI, "AddRefusedFault", PREFIX); 
    
    public static final QName ADD_RESPONSE_QNAME = 
        new QName(NAMESPACE_URI, "AddResponse", PREFIX);
    
    /**
     * 
     * The WS-A Action URI of the Add operation.
     * 
     */
    public static final String ADD_URI = NAMESPACE_URI + "/Add";
    
    public static final QName CONTENT_CREATION_FAILED_QNAME = 
        new QName(NAMESPACE_URI, "ContentCreationFailedFault", PREFIX);
    
    public static final String CONTENT_ELEMENTS = "ContentElements";
    
    /**
     * 
     * The name of the wssg:Content property.
     * 
     */
    public static final QName CONTENT_QNAME = 
        new QName(NAMESPACE_URI, "Content", PREFIX);
    
    /**
     * 
     * The name of the wssg:MembershipContentRule property.
     * 
     */
    public static final QName CONTENT_RULE_QNAME = 
        new QName(NAMESPACE_URI, "MembershipContentRule", PREFIX);
    
    /**
     * 
     * The name of the wssg:CurrentTime return value.
     * 
     */
    public static final QName CURRENT_TIME_QNAME = 
        new QName(NAMESPACE_URI, "CurrentTime", PREFIX);
    
    /**
     * 
     * The name of the WS-SG entry addition event.
     * 
     */
    public static final QName ENTRY_ADDITION_QNAME = 
        new QName(NAMESPACE_URI, "EntryAdditionNotification", PREFIX);
    
    /**
     * 
     * The name of the wssg:Entry property.
     * 
     */
    public static final QName ENTRY_QNAME = 
        new QName(NAMESPACE_URI, "Entry", PREFIX);
    
    /**
     * 
     * The name of the WS-SG entry destruction event.
     * 
     */
    public static final QName ENTRY_REMOVAL_QNAME = 
        new QName(NAMESPACE_URI, "EntryRemovalNotification", PREFIX);
    
    public static final QName INIT_TERMINATION_QNAME = 
        new QName(NAMESPACE_URI, "InitialTerminationTime", PREFIX);
    
    /**
     * 
     * The name of the wssg:MemberEPR property.
     * 
     */
    public static final QName MEMBER_EPR_QNAME = 
        new QName(NAMESPACE_URI, "MemberEPR", PREFIX);
    
    /**
     * 
     * The name of the wssg:MemberServiceEPR property.
     * 
     */
    public static final QName MEMBER_SERVICE_EPR_QNAME = 
        new QName(NAMESPACE_URI, "MemberServiceEPR", PREFIX);
    
    public static final String MEMBERSHIP_INTERFACE = "MembershipInterface";
    
    /**
     * 
     * The name of the WS-N Topic for WS-SG lifecycle events.
     * 
     */
    public static final String MODIFICATION_TOPIC_NAME = "ServiceGroupModification";
    
    /**
     * 
     * The name of the wssg:ServiceGroupEntryEPR property.
     * 
     */
    public static final QName SG_ENTRY_EPR_QNAME = 
        new QName(NAMESPACE_URI, "ServiceGroupEntryEPR", PREFIX);
    
    /**
     * 
     * The name of the wssg:ServiceGroupEntryReference return value.
     * 
     */
    public static final QName SG_ENTRY_REFERENCE_QNAME = 
        new QName(NAMESPACE_URI, "ServiceGroupEntryReference", PREFIX);
    
    /**
     * 
     * The name of the wssg:ServiceGroupEPR property.
     * 
     */
    public static final QName SG_EPR_QNAME = 
        new QName(NAMESPACE_URI, "ServiceGroupEPR", PREFIX);
    
    /**
     * 
     * The name of the wssg:TerminationTime return value.
     * 
     */
    public static final QName TERMINATION_TIME_QNAME = 
        new QName(NAMESPACE_URI, "TerminationTime", PREFIX);
    
    public static final QName UNSUPPORTED_MEMBER_INTERFACE_QNAME = 
        new QName(NAMESPACE_URI, "UnsupportedMemberInterfaceFault", PREFIX);
}
