/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.resource.properties.set.impl;

import org.w3c.dom.Element;

import org.apache.muse.core.routing.AbstractMessageHandler;
import org.apache.muse.ws.addressing.soap.SoapFault;
import org.apache.muse.ws.resource.properties.WsrpConstants;
import org.apache.muse.ws.resource.properties.set.SetOperationFactory;

/**
 *
 * SetHandler is the parser for the WS-ResourceProperties SetResourceProperties 
 * operation.
 *
 * @author Dan Jemiolo (danj)
 * 
 * @see org.apache.muse.ws.resource.properties.set.SetResourceProperties
 *
 */

public class SetHandler extends AbstractMessageHandler
{
    //
    // Used to parse all different types of SetResourceProperties
    //
    private static final SetOperationFactory _FACTORY = new SimpleSetOperationFactory();
    
    /**
     * 
     * The wsrp:SetResourcePropertiesResponse content is always the same, 
     * so we can share one instance of SetResponse among all components.
     * 
     */
    public static final SetResponse SET_RESPONSE = new SetResponse();
    
    public SetHandler()
    {
        super(WsrpConstants.SET_RESOURCE_PROPERTIES_URI, WsrpConstants.SET_QNAME);
    }
    
    public Object[] fromXML(Element xml) 
        throws SoapFault
    {
        return new Object[]{ _FACTORY.createSet(xml) };
    }
    
    public Element toXML(Object result)
    {
        return SET_RESPONSE.toXML();
    }
}
