/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
 
package org.apache.ws.resource.metadata.ext;

import org.w3c.dom.Element;

import org.apache.muse.ws.metadata.impl.SimpleMetadataExchange;
import org.apache.muse.ws.resource.WsResource;
import org.apache.muse.ws.resource.metadata.MetadataDescriptor;
import org.apache.muse.ws.resource.metadata.WsrmdConstants;

/**
 * 
 * WsrfMetadataExchange is an extension of the default WS-MEx implementation, 
 * {@linkplain SimpleMetadataExchange SimpleMetadataExchange}, which supports 
 * the WS0RF WS-ResourceMetadataDescriptor dialect. Calls to getMetadata() 
 * that use the WS-RMD namespace as the dialect will get the resource's 
 * metadata descriptor XML in response.
 *
 * @author Dan Jemiolo (danj)
 * 
 * @see WsrmdConstants#NAMESPACE_URI
 *
 */

public class WsrfMetadataExchange extends SimpleMetadataExchange
{
    public Element[] getMetadata(String dialect)
    {
        if (dialect != null && dialect.equals(WsrmdConstants.NAMESPACE_URI))
        {
            WsResource resource = (WsResource)getResource();
            MetadataDescriptor rmd = resource.getPropertyCollection().getMetadata();
            return new Element[]{ rmd.toXML() };
        }
        
        return super.getMetadata(dialect);
    }
}
