/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.ws.metadata.impl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.metadata.WsxConstants;

/**
 *
 * GetMetadataResponse is a serializer/deserializer for the WS-MetadataExchange 
 * GetMetadata operation's response content.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class GetMetadataResponse implements XmlSerializable
{
    //
    // The metadata fragments retrieved for GetMetadata (may be empty)
    //
    private Element[] _metadata = null;
    
    public GetMetadataResponse()
    {
        this(new Element[]{});
    }
    
    public GetMetadataResponse(Element[] metadata)
    {
        _metadata = metadata;
    }

    
    public Element[] getMetadata()
    {
        return _metadata;
    }
    
    public boolean isEmpty()
    {
        return _metadata.length == 0;
    }
    
    public Element toXML()
    {
        return toXML(XmlUtils.EMPTY_DOC);
    }
    
    public Element toXML(Document doc)
    {
        Element root = XmlUtils.createElement(doc, WsxConstants.METADATA_QNAME);
        
        for (int n = 0; n < _metadata.length; ++n)
        {
            Element section = XmlUtils.createElement(doc, WsxConstants.SECTION_QNAME, _metadata[n], false);
            root.appendChild(section);
        }
        
        return root;
    }
}
