/*=============================================================================*
 *  Copyright 2006 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/

package org.apache.muse.util.osgi;

import org.apache.muse.util.osgi.CapabilityPair;
import org.osgi.framework.Bundle;

/**
 * ResourceManagementImplementation is an interface for registering Muse contributions
 * provided by a bundle. Use this interface to register extensions that your bundle may
 * want to share with other bundles. Services implementing this interface will be consumed
 * by the <code>OSGiReflectUtilHelper</code>. Examples can be found in the OSGi packaging 
 * of the Muse API and IMPL bundles.
 *
 * @see org.apache.muse.core.platform.osgi.util.OSGiReflectUtilHelper 
 * @see org.apache.muse.osgi.wsdm.muws.MUWSImplementationService
 * @see org.apache.muse.osgi.wsdm.muws.impl.MUWSImplementationService
 * @author Joel Hawkins (joelh)
 *
 */
public interface ResourceManagementImplementation {
	public static final String IMPLEMENTATION_NAME = "implementation";
	
	/**
	 * returns the implementation name for the contributing bundle.
	 */
	String getImplementationName();
	/**
	 * returns an array of Resource Implementation Class names.
	 */
	String[] getResourceImplementationNames();
	/**
	 * returns an Array of Capability URI/Capability Implementation Class name pairs.
	 */
	CapabilityPair[] getResourceCapabilityMappings();
	/**
	 * returns an array of Specification Resource names (typically schema or wsdl file names)
	 */
	String[] getResourceSpecNames();
	
	Bundle getBundle();

}
